#!/bin/bash
#   author:martinmhan@yahoo.com date:  22/04/2014
#   scadat is a bash command line interface to the tango scada (and in future epics)
#   Copyright (C) <2014>  <Martin Mohan>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software Foundation,
#   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA

verbose=0
if [ x$1 = x"" ]; then 
    export verbose=0
else
    export verbose=1
fi

if [ -z "$TANGO_HOST" ]; then
    echo "set TANGO_HOST e.g. export TANGO_HOST=scadat.org:10000"
    exit 1
fi  
#export TANGO_HOST="localhost:10000"
source scadat_unittest.sh

ExecuteCmdEquals "scadat localhost:10000 -vv" "open: TANGO_HOST=localhost:10000"
ExecuteCmdEquals "scadat localhost:1234" "FAIL open: TANGO_HOST=localhost:1234"
ExecuteCmdEquals "scadat scadat.org:12345" "FAIL open: TANGO_HOST=scadat.org:12345"
ExecuteCmdEquals "scadat localhost:10000 -vv" "open: TANGO_HOST=localhost:10000"
ExecuteCmdContains "scadat Unknown -v" "set TANGO_HOST e.g. export TANGO_HOST=scadat.org:10000"
#ExecuteCmdContains "scadat -l Unknown:10000 -v" "PortScannerError"
ExecuteCmdContains "scadat -r test/simulator/rampx1" "Amplitude"
ExecuteCmdContains "scadat -c sys/tg_test/1 DevFloat 12.34" "12.34"

ExecuteCmdContains "scadat -c sys/tg_test/1" "Usage: scadat -c sys/tg_test/1 <cmd_name> <value>"
ExecuteCmdContains "scadat -c sys/tg_test/1 Status" "The device is"

ExecuteCmdEquals "scadat -c sys/tg_test/1 DevDouble 12.34" "12.34"
ExecuteCmdEquals "scadat -c sys/tg_test/1 DevLong 1234" "1234"
ExecuteCmdEquals "scadat -c sys/tg_test/1 DevLong64 1234" "1234"
ExecuteCmdEquals "scadat -c sys/tg_test/1 DevULong64 1234" "1234"
ExecuteCmdEquals "scadat -c sys/tg_test/1 DevULong 1234" "1234"
ExecuteCmdEquals "scadat -c sys/tg_test/1 DevBoolean 0" "False"
ExecuteCmdEquals "scadat -c sys/tg_test/1 DevBoolean 1" "True"
ExecuteCmdEquals "scadat -c sys/tg_test/1 DevShort 1234" "1234"
ExecuteCmdEquals "scadat -c sys/tg_test/1 DevUShort 1234" "1234"
ExecuteCmdEquals "scadat -c sys/tg_test/1 DevString 'my string'" "my string"
ExecuteCmdEquals "scadat -c sys/tg_test/1 DevVarLongArray '1 2 3 4'" "[1 2 3 4]"
ExecuteCmdEquals "scadat -c sys/tg_test/1 DevVarLong64Array '1 2 3 4'" "[1 2 3 4]"
ExecuteCmdEquals "scadat -c sys/tg_test/1 DevVarULong64Array '1 2 3 4'" "[1 2 3 4]"
ExecuteCmdContains "scadat -c sys/tg_test/1 DevVarFloatArray '1.123456 2.2 3.3 4.4'" "1.123456"
ExecuteCmdContains "scadat -c sys/tg_test/1 DevVarDoubleArray '1.123456 2.2 3.3 4.4'" "1.123456"
ExecuteCmdEquals "scadat -c sys/tg_test/1 DevVarUShortArray '1 2 3 4'" "[1 2 3 4]"
ExecuteCmdEquals "scadat -c sys/tg_test/1 DevVarShortArray '1 2 3 4'" "[1 2 3 4]"
ExecuteCmdEquals "scadat -c sys/tg_test/1 DevVarStringArray 'string1 string2 string3 string4'" "['string1', 'string2', 'string3', 'string4']"
ExecuteCmdEquals "scadat -c sys/tg_test/1 DevVoid None" "None"

# attribute_read_all
ExecuteCmdContains "scadat -r sys/tg_test/1 -v | grep long_scalar_rww" "long_scalar_rww"
ExecuteCmdContains "scadat -r sys/tg_test/1 -v | grep ulong_image_ro" "ulong_image_ro"

# attribute_read_single
#ExecuteCmdContains "scadat -r sys/tg_test/1 short_scalar_rww -v | grep 'short_scalar_rww'" "short_scalar_rww"
ExecuteCmdContains "scadat -r sys/tg_test/1 -v | grep 'short_scalar_rww'" "short_scalar_rww"
# Read 1 command
ExecuteCmdEquals "scadat -r sys/tg_test/1 | grep ushort_scalar" "ushort_scalar"
ExecuteCmdContains "scadat -r sys/tg_test/1_error" "Cannot Open device sys/tg_test/1_error on"
ExecuteCmdEquals "scadat -r sys/tg_test/1 | grep long_scalar_w" "long_scalar_w"
# Write/Read Attributes

ExecuteCmdEquals "scadat -w sys/tg_test/1" "Usage: scadat -w sys/tg_test/1 <attr_name> <value>"
ExecuteCmdEquals "scadat -w sys/tg_test/1 long_scalar_w" "Usage: scadat -w sys/tg_test/1  long_scalar_w <DevLong>"
ExecuteCmdEquals "scadat -w sys/tg_test/1 long_scalar_w 4321" "long_scalar_w->4321"
ExecuteCmdEquals "scadat -r sys/tg_test/1 -v | grep long_scalar_w" "long_scalar_w 4321"
ExecuteCmdEquals "scadat -w sys/tg_test/1 long_scalar_w 1234" "long_scalar_w->1234"
ExecuteCmdEquals "scadat -r sys/tg_test/1 -v | grep long_scalar_w" "long_scalar_w 1234"

ExecuteCmdEquals "scadat -w sys/tg_test/1 short_scalar_w 4321" "short_scalar_w->4321"
ExecuteCmdEquals "scadat -r sys/tg_test/1 -v | grep short_scalar_w" "short_scalar_w 4321"

ExecuteCmdEquals "scadat -w sys/tg_test/1 string_scalar 'my string 123'" "string_scalar->my string 123"
ExecuteCmdEquals "scadat -r sys/tg_test/1 -v | grep string_scalar" "string_scalar my string 123"
ExecuteCmdEquals "scadat -s scadat.org" "scadat.org"
#### Not supported - yet
#ExecuteCmdContains "$scadat -w sys/tg_test/1 DevVarDoubleStringArray '1 2 3 4'" "1 2 3 4"
#ExecuteCmdContains "$scadat -w sys/tg_test/1 DevVarCharArray '1 2 3 4'" "1 2 3 4"
#ExecuteCmdContains "$scadat -w sys/tg_test/1 DevVarLongStringArray 1234" "1234"
#echo "epics tests:"
#export SCADAT_HOST="EPICS"
#ExecuteCmdContains "$scadat -r 'CO_TEST:CLOCK1:SEC1' -v" "CO_TEST:CLOCK1:SEC1"
